==> pegasus-merchandise-api-2.3.7-sources.jar: com/thebeastshop/pegasus/merchandise/vo/OpProdDynmDetailsHistoryVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by gensheng.ye on 2019/1/2.
 */
public class OpProdDynmDetailsHistoryVO implements Serializable {

    private Long id;
    private String prodCode;
    private Integer prodId;
    private Integer dynmcontId;
    private Integer dynmType;
    private String dynmTitle;
    private String dynmContent;
    private Integer sort;
    private Integer columnSort;
    private Date createTime;
    private Integer createId;
    private String craeteMan;
    private String status;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getProdCode() {
        return prodCode;
    }

    public void setProdCode(String prodCode) {
        this.prodCode = prodCode;
    }

    public Integer getProdId() {
        return prodId;
    }

    public void setProdId(Integer prodId) {
        this.prodId = prodId;
    }

    public Integer getDynmcontId() {
        return dynmcontId;
    }

    public void setDynmcontId(Integer dynmcontId) {
        this.dynmcontId = dynmcontId;
    }

    public Integer getDynmType() {
        return dynmType;
    }

    public void setDynmType(Integer dynmType) {
        this.dynmType = dynmType;
    }

    public String getDynmTitle() {
        return dynmTitle;
    }

    public void setDynmTitle(String dynmTitle) {
        this.dynmTitle = dynmTitle;
    }

    public String getDynmContent() {
        return dynmContent;
    }

    public void setDynmContent(String dynmContent) {
        this.dynmContent = dynmContent;
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }

    public Integer getColumnSort() {
        return columnSort;
    }

    public void setColumnSort(Integer columnSort) {
        this.columnSort = columnSort;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Integer getCreateId() {
        return createId;
    }

    public void setCreateId(Integer createId) {
        this.createId = createId;
    }

    public String getCraeteMan() {
        return craeteMan;
    }

    public void setCraeteMan(String craeteMan) {
        this.craeteMan = craeteMan;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

}

==> pegasus-merchandise-api-3.4.0-sources.jar: com/thebeastshop/pegasus/merchandise/vo/OpProdDynmDetailsHistoryVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by gensheng.ye on 2019/1/2.
 */
public class OpProdDynmDetailsHistoryVO implements Serializable {

    private Long id;
    private String prodCode;
    private Integer prodId;
    private Integer dynmcontId;
    private Integer dynmType;
    private String dynmTitle;
    private String dynmContent;
    private Integer sort;
    private Integer columnSort;
    private Date createTime;
    private Integer createId;
    private String craeteMan;
    private String status;
    private String clearGap;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getProdCode() {
        return prodCode;
    }

    public void setProdCode(String prodCode) {
        this.prodCode = prodCode;
    }

    public Integer getProdId() {
        return prodId;
    }

    public void setProdId(Integer prodId) {
        this.prodId = prodId;
    }

    public Integer getDynmcontId() {
        return dynmcontId;
    }

    public void setDynmcontId(Integer dynmcontId) {
        this.dynmcontId = dynmcontId;
    }

    public Integer getDynmType() {
        return dynmType;
    }

    public void setDynmType(Integer dynmType) {
        this.dynmType = dynmType;
    }

    public String getDynmTitle() {
        return dynmTitle;
    }

    public void setDynmTitle(String dynmTitle) {
        this.dynmTitle = dynmTitle;
    }

    public String getDynmContent() {
        return dynmContent;
    }

    public void setDynmContent(String dynmContent) {
        this.dynmContent = dynmContent;
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }

    public Integer getColumnSort() {
        return columnSort;
    }

    public void setColumnSort(Integer columnSort) {
        this.columnSort = columnSort;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Integer getCreateId() {
        return createId;
    }

    public void setCreateId(Integer createId) {
        this.createId = createId;
    }

    public String getCraeteMan() {
        return craeteMan;
    }

    public void setCraeteMan(String craeteMan) {
        this.craeteMan = craeteMan;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getClearGap() {
        return clearGap;
    }

    public void setClearGap(String clearGap) {
        this.clearGap = clearGap;
    }


}
